"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 광역자치단체 이름을 축약합니다.
 * 두글자(충남, 서울) 등을 2글자로 지역 구분으로 바꿉니다.
 * 바뀌는 지역명에 대해서는 Readme.md를 참조하여 주시기 바랍니다.
 * @param list 지역명을 담고 있는 리스트입니다. ex) ['충남', '충북']
 * @param allow3words 3글자 지역명을 허용할지를 결정합니다.
 */
function shortProvinceName2(list, allow3words = false) {
    const temp = [];
    let jeonla = 0;
    let honam = false;
    let yeongnam = 0;
    let kyeongin = 0;
    let chungcheong = 0;
    let kyeongsang = 0;
    let hoseo = false;
    let buulgyeong = 0;
    let gyeonggi = false;
    const c = ['충북', '충남'];
    const j = ['전북', '전남'];
    const h = '광주';
    const s = '세종';
    const i = ['서울', '인천'];
    const k = ['경북', '경남'];
    const y = ['울산', '부산', '대구'];
    const b = ['부산', '울산', '경남'];
    const g = '경기';
    const KSHY = ['전북', '전남', '광주', '경북', '경남', '울산', '부산', '대구', '충북', '충남', '세종', '서울', '인천', '경기'];
    list.forEach(v => {
        if (c.includes(v))
            chungcheong++;
        else if (j.includes(v))
            jeonla++;
        else if (h === v)
            honam = true;
        else if (s === v)
            hoseo = true;
        else if (i.includes(v))
            kyeongin++;
        else if (k.includes(v))
            kyeongsang++;
        else if (y.includes(v))
            yeongnam++;
        else if (g === v)
            gyeonggi = true;
        if (b.includes(v))
            buulgyeong++;
    });
    honam = honam && jeonla === 2;
    hoseo = hoseo && chungcheong === 2;
    list.forEach(v => {
        if ((chungcheong === 1 && c.includes(v)) || (!hoseo && v === s) ||
            (jeonla === 1 && j.includes(v)) || (!honam && v === h) ||
            (kyeongsang === 1 && k.includes(v) && buulgyeong <= 2) || (kyeongsang === 1 && y.includes(v) && !b.includes(v)) || (buulgyeong <= 2 && kyeongsang === 1 && b.includes(v)) ||
            (kyeongin === 1 && i.includes(v)) || (kyeongin === 1 && v === g) ||
            !KSHY.includes(v))
            temp.push(v);
    });
    if (kyeongin === 2 && gyeonggi)
        temp.push('수도권');
    else if (kyeongin === 2)
        temp.push('경인');
    if (chungcheong === 2 && !hoseo)
        temp.push('충청');
    if (chungcheong === 2 && hoseo)
        temp.push('호서');
    if (jeonla === 2 && !honam)
        temp.push('전라');
    if (honam)
        temp.push('호남');
    if (kyeongsang === 2 && yeongnam !== 3)
        temp.push('경상');
    if (kyeongsang === 1 && buulgyeong === 3 && allow3words)
        temp.push('부울경');
    if (kyeongsang === 2 && yeongnam === 3)
        temp.push('영남');
    return temp;
}
exports.shortProvinceName2 = shortProvinceName2;
/**
 * 광역자치단체 이름을 축약합니다.
 * 두글자(충청남도, 서울특별시) 등을 2글자로 지역 구분으로 바꿉니다.
 * 바뀌는 지역명에 대해서는 Readme.md를 참조하여 주시기 바랍니다.
 * @param list 지역명을 담고 있는 리스트입니다. ex) ['충청남도', '충청북도']
 */
function shortProvinceName(list) {
    const temp = [];
    let jeonla = 0;
    let honam = false;
    let yeongnam = 0;
    let kyeongin = 0;
    let chungcheong = 0;
    let kyeongsang = 0;
    let hoseo = false;
    let buulgyeong = 0;
    let gyeonggi = false;
    const c = ['충청북도', '충청남도'];
    const j = ['전라북도', '전라남도'];
    const h = '광주광역시';
    const s = '세종특별자치시';
    const i = ['서울특별시', '인천광역시'];
    const k = ['경상북도', '경상남도'];
    const y = ['울산광역시', '부산광역시', '대구광역시'];
    const b = ['부산광역시', '울산광역시', '경상남도'];
    const g = '경기도';
    const KSHY = ['전라북도', '전라남도', '광주광역시', '경상북도', '경상남도', '부산광역시', '대구광역시', '울산광역시', '충청북도', '충청남도', '세종특별자치시', '서울특별시', '인천광역시', '경기도'];
    list = list.map(v => v.trim());
    list.forEach(v => {
        if (c.includes(v))
            chungcheong++;
        else if (j.includes(v))
            jeonla++;
        else if (h === v)
            honam = true;
        else if (s === v)
            hoseo = true;
        else if (i.includes(v))
            kyeongin++;
        else if (k.includes(v))
            kyeongsang++;
        else if (y.includes(v))
            yeongnam++;
        else if (g === v)
            gyeonggi = true;
        if (b.includes(v))
            buulgyeong++;
    });
    honam = honam && jeonla === 2;
    hoseo = hoseo && chungcheong === 2;
    list.forEach(v => {
        if ((chungcheong === 1 && c.includes(v)) || (!hoseo && v === s) ||
            (jeonla === 1 && j.includes(v)) || (!honam && v === h) ||
            (kyeongsang === 1 && k.includes(v) && buulgyeong <= 2) || (kyeongsang === 1 && y.includes(v) && !b.includes(v)) || (buulgyeong <= 2 && kyeongsang === 1 && b.includes(v)) ||
            (kyeongin === 1 && i.includes(v)) || (kyeongin === 1 && v === g) ||
            !KSHY.includes(v))
            temp.push(v);
    });
    if (kyeongin === 2 && gyeonggi)
        temp.push('수도권');
    else if (kyeongin === 2)
        temp.push('경인 지방');
    if (chungcheong === 2 && !hoseo)
        temp.push('충청도');
    if (chungcheong === 2 && hoseo)
        temp.push('호서 지방');
    if (jeonla === 2 && !honam)
        temp.push("전라도");
    if (honam)
        temp.push("호남 지방");
    if (kyeongsang === 2 && yeongnam !== 3)
        temp.push("경상도");
    if (kyeongsang === 1 && buulgyeong === 3)
        temp.push('부울경');
    if (kyeongsang === 2 && yeongnam === 3)
        temp.push("영남 지방");
    return temp;
}
exports.shortProvinceName = shortProvinceName;
function japanese(list, mode = 2) {
    const data = {
        전라북도: { kanji: '全羅北道', katakana: 'チョンラプクト', kanjiKatakana: '全羅(チョルラ)北道' },
        전라남도: { kanji: '全羅南道', katakana: 'チョンラナムド', kanjiKatakana: '全羅(チョルラ)南道' },
        광주광역시: { kanji: '光州広域市', katakana: 'クァンジュグァンヨクシ', kanjiKatakana: '光州(クァンジュ)広域市' },
        경상북도: { kanji: '慶尙北道', katakana: 'キョンサンプクト', kanjiKatakana: '慶尙(キョンサン)北道' },
        경상남도: { kanji: '慶尙南道', katakana: 'キョンサンナムド', kanjiKatakana: '慶尙(キョンサン)南道' },
        부산광역시: { kanji: '釜山広域市', katakana: 'プサングァンヨクシ', kanjiKatakana: '釜山(プサン)広域市' },
        대구광역시: { kanji: '大邱広域市', katakana: 'テググァンヨクシ', kanjiKatakana: '大邱(テグ)広域市' },
        울산광역시: { kanji: '蔚山広域市', katakana: 'ウルサングァンヨクシ', kanjiKatakana: '蔚山(ウルサン)広域市' },
        대전광역시: { kanji: '大田広域市', katakana: 'テジョングァンヨクシ', kanjiKatakana: '大田(テジョン)広域市' },
        충청북도: { kanji: '忠清北道', katakana: 'チュンチョンプクト', kanjiKatakana: '忠清(チュンチョン)北道' },
        충청남도: { kanji: '忠清南道', katakana: 'チュンチョンナムド', kanjiKatakana: '忠清(チュンチョン)南道' },
        세종특별자치시: { kanji: '世宗特別自治市', katakana: 'セジョントゥクピョルジャチシ', kanjiKatakana: '世宗(セジョン)特別自治市' },
        서울특별시: { kanji: 'ソウル特別市', katakana: 'ソウルトゥクピョルシ', kanjiKatakana: 'ソウル特別市' },
        인천광역시: { kanji: '仁川広域市', katakana: 'インチョングァンヨクシ', kanjiKatakana: '仁川(インチョン)広域市' },
        강원도: { kanji: '江原道', katakana: 'カンウォンド', kanjiKatakana: '江原(カンウォン)道' },
        경기도: { kanji: '京畿道', katakana: 'キョンギド', kanjiKatakana: '京畿(キョンギ)道' },
        제주특별자치도: { kanji: '済州特別自治道', katakana: 'チェジュトゥクピョルジャチド', kanjiKatakana: '済州(チェジュ)特別自治道' },
        강남구: { kanji: '江南区', katakana: 'カンナムグ', kanjiKatakana: '江南(カンナム)区' },
        강동구: { kanji: '江東区', katakana: 'カンドング', kanjiKatakana: '江東(カンドン)区' },
        강북구: { kanji: '江北区', katakana: 'カンブクグ', kanjiKatakana: '江北(カンブク)区' },
        강서구: { kanji: '江西区', katakana: 'カンソグ', kanjiKatakana: '江西(カンソ)区' },
        관악구: { kanji: '冠岳区', katakana: 'クァナクグ', kanjiKatakana: '冠岳(クァナク)区' },
        광진구: { kanji: '広津区', katakana: 'クァンジング', kanjiKatakana: '広津(クァンジン)区' },
        구로구: { kanji: '九老区', katakana: 'クログ', kanjiKatakana: '九老(クロ)区' },
        금천구: { kanji: '衿川区', katakana: 'クムチョング', kanjiKatakana: '衿川(クムチョン)区' },
        노원구: { kanji: '蘆原区', katakana: 'ノウォング', kanjiKatakana: '蘆原(ノウォン)区' },
        도봉구: { kanji: '道峰区', katakana: 'トボング', kanjiKatakana: '道峰(トボン)区' },
        동대문구: { kanji: '東大門区', katakana: 'トンデムング', kanjiKatakana: '東大門(トンデムン)区' },
        동작구: { kanji: '銅雀区', katakana: 'トンジャクグ', kanjiKatakana: '銅雀(トンジャク)区' },
        마포구: { kanji: '麻浦区', katakana: 'マポグ', kanjiKatakana: '麻浦(マポ)区' },
        서대문구: { kanji: '西大門区', katakana: 'ソデムング', kanjiKatakana: '西大門(ソデムン)区' },
        서초구: { kanji: '瑞草区', katakana: 'ソチョグ', kanjiKatakana: '瑞草(ソチョ)区' },
        성동구: { kanji: '城東区', katakana: 'ソンドング', kanjiKatakana: '城東(ソンドン)区' },
        성북구: { kanji: '城北区', katakana: 'ソンブクグ', kanjiKatakana: '城北(ソンブク)区' },
        송파구: { kanji: '松坡区', katakana: 'ソンパグ', kanjiKatakana: '松坡(ソンパ)区' },
        양천구: { kanji: '陽川区', katakana: 'ヤンチョング', kanjiKatakana: '陽川(ヤンチョン)区' },
        영등포구: { kanji: '永登浦区', katakana: 'ヨンドゥンポグ', kanjiKatakana: '永登浦(ヨンドゥンポ)区' },
        용산구: { kanji: '龍山区', katakana: 'ヨンサング', kanjiKatakana: '龍山(ヨンサン)区' },
        은평구: { kanji: '恩平区', katakana: 'ウンピョング', kanjiKatakana: '恩平(ウンピョン)区' },
        종로구: { kanji: '鍾路区', katakana: 'チョンノグ', kanjiKatakana: '鍾路(チョンノ)区' },
        중구: { kanji: '中区', katakana: 'チュング', kanjiKatakana: '中(チュン)区' },
        중랑구: { kanji: '中浪区', katakana: 'チュンナング', kanjiKatakana: '中浪(チュンナン)区' },
        금정구: { kanji: '金井区', katakana: 'クムジョング', kanjiKatakana: '金井(クムジョン)区' },
        기장군: { kanji: '機張郡', katakana: 'キジャングン', kanjiKatakana: '機張(キジャン)郡' },
        남구: { kanji: '南区', katakana: 'ナムグ', kanjiKatakana: '南(ナム)区' },
        동구: { kanji: '東区', katakana: 'トング', kanjiKatakana: '東(トン)区' },
        동래구: { kanji: '東萊区', katakana: 'トンネグ', kanjiKatakana: '東萊(トンネ)区' },
        부산진구: { kanji: '釜山鎮区', katakana: 'プサンジング', kanjiKatakana: '釜山鎮(プサンジン)区' },
        북구: { kanji: '北区', katakana: 'プクグ', kanjiKatakana: '北(プク)区' },
        사상구: { kanji: '沙上区', katakana: 'ササング', kanjiKatakana: '沙上(ササン)区' },
        사하구: { kanji: '沙下区', katakana: 'サハグ', kanjiKatakana: '沙下(サハ)区' },
        서구: { kanji: '西区', katakana: 'ソグ', kanjiKatakana: '西(ソ)区' },
        수영구: { kanji: '水営区', katakana: 'スヨング', kanjiKatakana: '水営(スヨン)区' },
        연제구: { kanji: '蓮堤区', katakana: 'ヨンジェグ', kanjiKatakana: '蓮堤(ヨンジェ)区' },
        영도구: { kanji: '影島区', katakana: 'ヨンドグ', kanjiKatakana: '影島(ヨンド)区' },
        해운대구: { kanji: '海雲台区', katakana: 'ヘウンデグ', kanjiKatakana: '海雲台(ヘウンデ)区' },
        계양구: { kanji: '桂陽区', katakana: 'キェヤング', kanjiKatakana: '桂陽(キェヤン)区' },
        남동구: { kanji: '南洞区', katakana: 'ナムドング', kanjiKatakana: '南洞(ナムドン)区' },
        부평구: { kanji: '富平区', katakana: 'プピョング', kanjiKatakana: '富平(プピョン)区' },
        미추훌구: { kanji: '弥鄒忽区', katakana: 'ミチュホルグ', kanjiKatakana: '弥鄒忽(ミチュホル)区' },
        연수구: { kanji: '延寿区', katakana: 'ヨンスグ', kanjiKatakana: '延寿(ヨンス)区' },
        강화군: { kanji: '江華郡', katakana: 'カンファグン', kanjiKatakana: '江華(カンファ)郡' },
        옹진군: { kanji: '甕津郡', katakana: 'オンジングン', kanjiKatakana: '甕津(オンジン)郡' },
        달서구: { kanji: '達西区', katakana: 'タルソグ', kanjiKatakana: '達西(タルソ)区' },
        수성구: { kanji: '寿城区', katakana: 'スソング', kanjiKatakana: '寿城(スソン)区' },
        달성군: { kanji: '達城郡', katakana: 'タルソングン', kanjiKatakana: '達城(タルソン)郡' },
        대덕구: { kanji: '大徳区', katakana: 'テドクグ', kanjiKatakana: '大徳(テドク)区' },
        유성구: { kanji: '儒城区', katakana: 'ユソング', kanjiKatakana: '儒城(ユソン)区' },
        광산구: { kanji: '光山区', katakana: 'クァンサング', kanjiKatakana: '光山(クァンサン)区' },
        울주군: { kanji: '蔚州郡', katakana: 'ウルジュグン', kanjiKatakana: '蔚州(ウルジュ)郡' },
        가평군: { kanji: '加平郡', katakana: 'カピョングン', kanjiKatakana: '加平(カピョン)郡' },
        고양시: { kanji: '高陽市', katakana: 'コヤンシ', kanjiKatakana: '高陽(コヤン)市' },
        덕양구: { kanji: '徳陽区', katakana: 'トクヤング', kanjiKatakana: '徳陽(トクヤン)区' },
        일산동구: { kanji: '一山東区', katakana: 'イルサンドング', kanjiKatakana: '一山東(イルサンドン)区' },
        일산서구: { kanji: '一山西区', katakana: 'イルサンソグ', kanjiKatakana: '一山西(イルサンソ)区' },
        과천시: { kanji: '果川市', katakana: 'クァチョンシ', kanjiKatakana: '果川(クァチョン)市' },
        광명시: { kanji: '光明市', katakana: 'クァンミョンシ', kanjiKatakana: '光明(クァンミョン)市' },
        광주시: { kanji: '広州市', katakana: 'クァンジュシ', kanjiKatakana: '広州(クァンジュ)市' },
        구리시: { kanji: '九里市', katakana: 'クリシ', kanjiKatakana: '九里(クリ)市' },
        군포시: { kanji: '軍浦市', katakana: 'クンポシ', kanjiKatakana: '軍浦(クンポ)市' },
        김포시: { kanji: '金浦市', katakana: 'キムポシ', kanjiKatakana: '金浦(キムポ)市' },
        남양주시: { kanji: '南楊州市', katakana: 'ナムヤンジュシ', kanjiKatakana: '南楊州(ナムヤンジュ)市' },
        동두천시: { kanji: '東豆川市', katakana: 'トンドゥチョンシ', kanjiKatakana: '東豆川(トンドゥチョン)市' },
        부천시: { kanji: '富川市', katakana: 'プチョンシ', kanjiKatakana: '富川(プチョン)市' },
        성남시: { kanji: '城南市', katakana: 'ソンナムシ', kanjiKatakana: '城南(ソンナム)市' },
        분당구: { kanji: '盆唐区', katakana: 'プンダング', kanjiKatakana: '盆唐(プンダン)区' },
        수정구: { kanji: '寿井区', katakana: 'スジョング', kanjiKatakana: '寿井(スジョン)区' },
        중원구: { kanji: '中院区', katakana: 'チュンウォング', kanjiKatakana: '中院(チュンウォン)区' },
        수원시: { kanji: '水原市', katakana: 'スウォンシ', kanjiKatakana: '水原(スウォン)市' },
        권선구: { kanji: '勧善区', katakana: 'クォンソング', kanjiKatakana: '勧善(クォンソン)区' },
        영통구: { kanji: '靈通区', katakana: 'ヨントング', kanjiKatakana: '靈通(ヨントン)区' },
        장안구: { kanji: '長安区', katakana: 'チャンアング', kanjiKatakana: '長安(チャンアン)区' },
        팔달구: { kanji: '八達区', katakana: 'パルダルグ', kanjiKatakana: '八達(パルダル)区' },
        시흥시: { kanji: '始興市', katakana: 'シフンシ', kanjiKatakana: '始興(シフン)市' },
        안산시: { kanji: '安山市', katakana: 'アンサンシ', kanjiKatakana: '安山(アンサン)市' },
        단원구: { kanji: '檀園区', katakana: 'タヌォング', kanjiKatakana: '檀園(タヌォン)区' },
        상록구: { kanji: '常緑区', katakana: 'サンノクグ', kanjiKatakana: '常緑(サンノク)区' },
        안성시: { kanji: '安城市', katakana: 'アンソンシ', kanjiKatakana: '安城(アンソン)市' },
        안양시: { kanji: '安養市', katakana: 'アンヤンシ', kanjiKatakana: '安養(アンヤン)市' },
        동안구: { kanji: '東安区', katakana: 'トンアング', kanjiKatakana: '東安(トンアン)区' },
        만안구: { kanji: '万安区', katakana: 'マナング', kanjiKatakana: '万安(マナン)区' },
        양주시: { kanji: '楊州市', katakana: 'ヤンジュシ', kanjiKatakana: '楊州(ヤンジュ)市' },
        양평군: { kanji: '楊平郡', katakana: 'ヤンピョングン', kanjiKatakana: '楊平(ヤンピョン)郡' },
        여주시: { kanji: '驪州市', katakana: 'ヨジュシ', kanjiKatakana: '驪州(ヨジュ)市' },
        연천군: { kanji: '漣川郡', katakana: 'ヨンチョングン', kanjiKatakana: '漣川(ヨンチョン)郡' },
        오산시: { kanji: '烏山市', katakana: 'オサンシ', kanjiKatakana: '烏山(オサン)市' },
        용인시: { kanji: '龍仁市', katakana: 'ヨンインシ', kanjiKatakana: '龍仁(ヨンイン)市' },
        기흥구: { kanji: '器興区', katakana: 'キフング', kanjiKatakana: '器興(キフン)区' },
        수지구: { kanji: '水枝区', katakana: 'スジグ', kanjiKatakana: '水枝(スジ)区' },
        처인구: { kanji: '処仁区', katakana: 'チョイング', kanjiKatakana: '処仁(チョイン)区' },
        의왕시: { kanji: '義王市', katakana: 'ウィワンシ', kanjiKatakana: '義王(ウィワン)市' },
        의정부시: { kanji: '議政府市', katakana: 'ウィジョンブシ', kanjiKatakana: '議政府(ウィジョンブ)市' },
        이천시: { kanji: '利川市', katakana: 'イチョンシ', kanjiKatakana: '利川(イチョン)市' },
        파주시: { kanji: '坡州市', katakana: 'パジュシ', kanjiKatakana: '坡州(パジュ)市' },
        평택시: { kanji: '平沢市', katakana: 'ピョンテクシ', kanjiKatakana: '平沢(ピョンテク)市' },
        포천시: { kanji: '抱川市', katakana: 'ポチョンシ', kanjiKatakana: '抱川(ポチョン)市' },
        하남시: { kanji: '河南市', katakana: 'ハナムシ', kanjiKatakana: '河南(ハナム)市' },
        화성시: { kanji: '華城市', katakana: 'ファソンシ', kanjiKatakana: '華城(ファソンシ)市' },
        강릉시: { kanji: '江陵市', katakana: 'カンヌンシ', kanjiKatakana: '江陵(カンヌン)市' },
        '고성군(강원)': { kanji: '高城郡', katakana: 'コソングン', kanjiKatakana: '高城(コソン)郡' },
        동해시: { kanji: '東海市', katakana: 'トンヘシ', kanjiKatakana: '東海(トンヘ)市' },
        삼척시: { kanji: '三陟市', katakana: 'サムチョクシ', kanjiKatakana: '三陟(サムチョク)市' },
        속초시: { kanji: '束草市', katakana: 'ソクチョシ', kanjiKatakana: '束草(ソクチョ)市' },
        양구군: { kanji: '楊口郡', katakana: 'ヤンググン', kanjiKatakana: '楊口(ヤング)郡' },
        양양군: { kanji: '襄陽郡', katakana: 'ヤンヤングン', kanjiKatakana: '襄陽(ヤンヤン)郡' },
        영월군: { kanji: '寧越郡', katakana: 'ヨンウォルグン', kanjiKatakana: '寧越(ヨンウォル)郡' },
        원주시: { kanji: '原州市', katakana: 'ウォンジュシ', kanjiKatakana: '原州(ウォンジュ)市' },
        인제군: { kanji: '麟蹄郡', katakana: 'インジェグン', kanjiKatakana: '麟蹄(インジェ)郡' },
        정선군: { kanji: '旌善郡', katakana: 'チョンソングン', kanjiKatakana: '旌善(チョンソン)郡' },
        철원군: { kanji: '鉄原郡', katakana: 'チョルウォングン', kanjiKatakana: '鉄原(チョルウォン)郡' },
        춘천시: { kanji: '春川市', katakana: 'チュンチョンシ', kanjiKatakana: '春川(チュンチョン)市' },
        태백시: { kanji: '太白市', katakana: 'テベクシ', kanjiKatakana: '太白(テベク)市' },
        평창군: { kanji: '平昌郡', katakana: 'ピョンチャングン', kanjiKatakana: '平昌(ピョンチャン)郡' },
        홍천군: { kanji: '洪川郡', katakana: 'ホンチョングン', kanjiKatakana: '洪川(ホンチョン)郡' },
        화천군: { kanji: '華川郡', katakana: 'ファチョングン', kanjiKatakana: '華川(ファチョン)郡' },
        횡성군: { kanji: '横城郡', katakana: 'フェンソングン', kanjiKatakana: '横城(フェンソン)郡' },
        괴산군: { kanji: '槐山郡', katakana: 'クェサングン', kanjiKatakana: '槐山(クェサン)郡' },
        단양군: { kanji: '丹陽郡', katakana: 'タンヤングン', kanjiKatakana: '丹陽(タンヤン)郡' },
        보은군: { kanji: '報恩郡', katakana: 'ポウングン', kanjiKatakana: '報恩(ポウン)郡' },
        영동군: { kanji: '永同郡', katakana: 'ヨンドングン', kanjiKatakana: '永同(ヨンドン)郡' },
        옥천군: { kanji: '沃川郡', katakana: 'オクチョングン', kanjiKatakana: '沃川(オクチョン)郡' },
        음성군: { kanji: '陰城郡', katakana: 'ウムソングン', kanjiKatakana: '陰城(ウムソン)郡' },
        제천시: { kanji: '堤川市', katakana: 'チェチョンシ', kanjiKatakana: '堤川(チェチョン)市' },
        증평군: { kanji: '曽坪郡', katakana: 'チュンピョングン', kanjiKatakana: '曽坪(チュンピョン)郡' },
        진천군: { kanji: '鎮川郡', katakana: 'チンチョングン', kanjiKatakana: '鎮川(チンチョン)郡' },
        청주시: { kanji: '清州市', katakana: 'チョンジュシ', kanjiKatakana: '清州(チョンジュ)市' },
        상당구: { kanji: '上党区', katakana: 'サンダング', kanjiKatakana: '上党(サンダン)区' },
        서원구: { kanji: '西原区', katakana: 'ソウォング', kanjiKatakana: '西原(ソウォン)区' },
        청원구: { kanji: '清原区', katakana: 'チョンウォング', kanjiKatakana: '清原(チョンウォン)区' },
        흥덕구: { kanji: '興徳区', katakana: 'フンドクグ', kanjiKatakana: '興徳(フンドク)区' },
        충주시: { kanji: '忠州市', katakana: 'チュンジュシ', kanjiKatakana: '忠州(チュンジュ)市' },
        계룡시: { kanji: '鶏竜市', katakana: 'キェリョンシ', kanjiKatakana: '鶏竜(キェリョン)市' },
        공주시: { kanji: '公州市', katakana: 'コンジュシ', kanjiKatakana: '公州(コンジュ)市' },
        금산군: { kanji: '錦山郡', katakana: 'クムサングン', kanjiKatakana: '錦山(クムサン)郡' },
        논산시: { kanji: '論山市', katakana: 'ノンサンシ', kanjiKatakana: '論山(ノンサン)市' },
        당진시: { kanji: '唐津市', katakana: 'タンジンシ', kanjiKatakana: '唐津(タンジン)市' },
        보령시: { kanji: '保寧市', katakana: 'ポリョンシ', kanjiKatakana: '保寧(ポリョン)市' },
        부여군: { kanji: '扶余郡', katakana: 'プヨグン', kanjiKatakana: '扶余(プヨ)郡' },
        서산시: { kanji: '瑞山市', katakana: 'ソサンシ', kanjiKatakana: '瑞山(ソサン)市' },
        서천군: { kanji: '舒川郡', katakana: 'ソチョングン', kanjiKatakana: '舒川(ソチョン)郡' },
        아산시: { kanji: '牙山市', katakana: 'アサンシ', kanjiKatakana: '牙山(アサン)市' },
        예산군: { kanji: '禮山郡', katakana: 'イェサングン', kanjiKatakana: '禮山(イェサン)郡' },
        천안시: { kanji: '天安市', katakana: 'チョナンシ', kanjiKatakana: '天安(チョナン)市' },
        동남구: { kanji: '東南区', katakana: 'トンナムグ', kanjiKatakana: '東南(トンナム)区' },
        서북구: { kanji: '西北区', katakana: 'ソブクグ', kanjiKatakana: '西北(ソブク)区' },
        청양군: { kanji: '青陽郡', katakana: 'チョンヤングン', kanjiKatakana: '青陽(チョンヤン)郡' },
        태안군: { kanji: '泰安郡', katakana: 'テアングン', kanjiKatakana: '泰安(テアン)郡' },
        홍성군: { kanji: '洪城郡', katakana: 'ホンソングン', kanjiKatakana: '洪城(ホンソン)郡' },
        고창군: { kanji: '高敞郡', katakana: 'コチャングン', kanjiKatakana: '高敞(コチャン)郡' },
        군산시: { kanji: '群山市', katakana: 'クンサンシ', kanjiKatakana: '群山(クンサン)市' },
        김제시: { kanji: '金堤市', katakana: 'キムジェシ', kanjiKatakana: '金堤(キムジェ)市' },
        남원시: { kanji: '南原市', katakana: 'ナムウォンシ', kanjiKatakana: '南原(ナムウォン)市' },
        무주군: { kanji: '茂朱郡', katakana: 'ムジュグン', kanjiKatakana: '茂朱(ムジュ)郡' },
        부안군: { kanji: '扶安郡', katakana: 'プアングン', kanjiKatakana: '扶安(プアン)郡' },
        순창군: { kanji: '淳昌郡', katakana: 'スンチャングン', kanjiKatakana: '淳昌(スンチャン)郡' },
        완주군: { kanji: '完州郡', katakana: 'ワンジュグン', kanjiKatakana: '完州(ワンジュ)郡' },
        익산시: { kanji: '益山市', katakana: 'イクサンシ', kanjiKatakana: '益山(イクサン)市' },
        임실군: { kanji: '任実郡', katakana: 'イムシルグン', kanjiKatakana: '任実(イムシル)郡' },
        장수군: { kanji: '長水郡', katakana: 'チャンスグン', kanjiKatakana: '長水(チャンス)郡' },
        전주시: { kanji: '全州市', katakana: 'チョンジュシ', kanjiKatakana: '全州(チョンジュ)市' },
        덕진구: { kanji: '徳津区', katakana: 'トクチング', kanjiKatakana: '徳津(トクチン)区' },
        완산구: { kanji: '完山区', katakana: 'ワンサング', kanjiKatakana: '完山(ワンサン)区' },
        정읍시: { kanji: '井邑市', katakana: 'チョンウブシ', kanjiKatakana: '井邑(チョンウブ)市' },
        진안군: { kanji: '鎮安郡', katakana: 'チナングン', kanjiKatakana: '鎮安(チナン)郡' },
        강진군: { kanji: '康津郡', katakana: 'カンジングン', kanjiKatakana: '康津(カンジン)郡' },
        고흥군: { kanji: '高興郡', katakana: 'コフングン', kanjiKatakana: '高興(コフン)郡' },
        곡성군: { kanji: '谷成郡', katakana: 'コクソングン', kanjiKatakana: '谷成(コクソン)郡' },
        광양시: { kanji: '光陽市', katakana: 'クァンヤンシ', kanjiKatakana: '光陽(クァンヤン)市' },
        구례군: { kanji: '求礼郡', katakana: 'クリェグン', kanjiKatakana: '求礼(クリェ)郡' },
        나주시: { kanji: '羅州市', katakana: 'ナジュシ', kanjiKatakana: '羅州(ナジュ)市' },
        담양군: { kanji: '潭陽郡', katakana: 'タムヤングン', kanjiKatakana: '潭陽(タムヤン)郡' },
        목포시: { kanji: '木浦市', katakana: 'モクポシ', kanjiKatakana: '木浦(モクポ)市' },
        무안군: { kanji: '務安郡', katakana: 'ムアングン', kanjiKatakana: '務安(ムアン)郡' },
        보성군: { kanji: '宝城郡', katakana: 'ポソングン', kanjiKatakana: '宝城(ポソン)郡' },
        순천시: { kanji: '順天市', katakana: 'スンチョンシ', kanjiKatakana: '順天(スンチョン)市' },
        신안군: { kanji: '新安郡', katakana: 'シナングン', kanjiKatakana: '新安(シナン)郡' },
        여수시: { kanji: '麗水市', katakana: 'ヨスシ', kanjiKatakana: '麗水(ヨス)市' },
        영광군: { kanji: '靈光郡', katakana: 'ヨングァングン', kanjiKatakana: '靈光(ヨングァン)郡' },
        영암군: { kanji: '靈岩郡', katakana: 'ヨンアムグン', kanjiKatakana: '靈岩(ヨンアム)郡' },
        완도군: { kanji: '莞島郡', katakana: 'ワンドグン', kanjiKatakana: '莞島(ワンド)郡' },
        장성군: { kanji: '長城郡', katakana: 'チャンソングン', kanjiKatakana: '長城(チャンソン)郡' },
        장흥군: { kanji: '長興郡', katakana: 'チャンフングン', kanjiKatakana: '長興(チャンフン)郡' },
        진도군: { kanji: '珍島郡', katakana: 'チンドグン', kanjiKatakana: '珍島(チンド)郡' },
        함평군: { kanji: '咸平郡', katakana: 'ハムピョングン', kanjiKatakana: '咸平(ハムピョン)郡' },
        해남군: { kanji: '海南郡', katakana: 'ヘナムグン', kanjiKatakana: '海南(ヘナム)郡' },
        화순군: { kanji: '和順郡', katakana: 'ファスングン', kanjiKatakana: '和順(ファスン)郡' },
        경산시: { kanji: '慶山市', katakana: 'キョンサンシ', kanjiKatakana: '慶山(キョンサン)市' },
        경주시: { kanji: '慶州市', katakana: 'キョンジュシ', kanjiKatakana: '慶州(キョンジュ)市' },
        고령군: { kanji: '高霊郡', katakana: 'コリョングン', kanjiKatakana: '高霊(コリョン)郡' },
        구미시: { kanji: '亀尾市', katakana: 'クミシ', kanjiKatakana: '亀尾(クミ)市' },
        군위군: { kanji: '軍威郡', katakana: 'クヌィグン', kanjiKatakana: '軍威(クヌィ)郡' },
        김천시: { kanji: '金泉市', katakana: 'キムチョンシ', kanjiKatakana: '金泉(キムチョン)市' },
        문경시: { kanji: '聞慶市', katakana: 'ムンギョンシ', kanjiKatakana: '聞慶(ムンギョン)市' },
        봉화군: { kanji: '奉化郡', katakana: 'ポンファグン', kanjiKatakana: '奉化(ポンファ)郡' },
        상주시: { kanji: '尙州市', katakana: 'サンジュシ', kanjiKatakana: '尙州(サンジュ)市' },
        성주군: { kanji: '星州郡', katakana: 'ソンジュグン', kanjiKatakana: '星州(ソンジュ)郡' },
        안동시: { kanji: '安東市', katakana: 'アンドンシ', kanjiKatakana: '安東(アンドン)市' },
        영덕군: { kanji: '盈徳郡', katakana: 'ヨンドククン' },
        영양군: { kanji: '英陽郡', katakana: 'ヨンヤングン', kanjiKatakana: '英陽(ヨンヤン)郡' },
        영주시: { kanji: '栄州市', katakana: 'ヨンジュシ', kanjiKatakana: '栄州(ヨンジュ)市' },
        영천시: { kanji: '永川市', katakana: 'ヨンチョンシ', kanjiKatakana: '永川(ヨンチョン)市' },
        예천군: { kanji: '醴泉郡', katakana: 'イェチョングン', kanjiKatakana: '醴泉(イェチョン)郡' },
        울릉군: { kanji: '欝陵郡', katakana: 'ウルルングン', kanjiKatakana: '欝陵(ウルルン)郡' },
        울진군: { kanji: '蔚珍郡', katakana: 'ウルジングン', kanjiKatakana: '蔚珍(ウルジン)郡' },
        의성군: { kanji: '義城郡', katakana: 'ウィソングン', kanjiKatakana: '義城(ウィソン)郡' },
        청도군: { kanji: '清道郡', katakana: 'チョンドグン', kanjiKatakana: '清道(チョンド)郡' },
        청송군: { kanji: '青松郡', katakana: 'チョンソングン', kanjiKatakana: '青松(チョンソン)郡' },
        칠곡군: { kanji: '漆谷郡', katakana: 'チルゴクグン', kanjiKatakana: '漆谷(チルゴク)郡' },
        포항시: { kanji: '浦項市', katakana: 'ポハンシ', kanjiKatakana: '浦項(ポハン)市' },
        창원시: { kanji: '昌原市', katakana: 'チャンウォンシ', kanjiKatakana: '昌原(チャンウォン)市' },
        거제시: { kanji: '巨済市', katakana: 'コジェシ', kanjiKatakana: '巨済(コジェ)市' },
        거창군: { kanji: '居昌郡', katakana: 'コチャングン', kanjiKatakana: '居昌(コチャン)郡' },
        '고성군(경남)': { kanji: '固城郡', katakana: 'コソングン', kanjiKatakana: '固城(コソン)郡' },
        김해시: { kanji: '金海市', katakana: 'キムヘシ', kanjiKatakana: '金海(キムヘ)市' },
        남해군: { kanji: '南海郡', katakana: 'ナムヘグン', kanjiKatakana: '南海(ナムヘ)郡' },
        밀양시: { kanji: '密陽市', katakana: 'ミルヤンシ', kanjiKatakana: '密陽(ミルヤン)市' },
        사천시: { kanji: '泗川市', katakana: 'サチョンシ', kanjiKatakana: '泗川(サチョン)市' },
        산청군: { kanji: '山清郡', katakana: 'サンチョングン', kanjiKatakana: '山清(サンチョン)郡' },
        양산시: { kanji: '梁山市', katakana: 'ヤンサンシ', kanjiKatakana: '梁山(ヤンサン)市' },
        의령군: { kanji: '宜寧郡', katakana: 'ウィリョングン', kanjiKatakana: '宜寧(ウィリョン)郡' },
        진주시: { kanji: '晋州市', katakana: 'チンジュシ', kanjiKatakana: '晋州(チンジュ)市' },
        창녕군: { kanji: '昌寧郡', katakana: 'チャンニョングン', kanjiKatakana: '昌寧(チャンニョン)郡' },
        마산합포구: { kanji: '馬山合浦区', katakana: 'マサンハブポグ', kanjiKatakana: '馬山合浦(マサンハブポ)区' },
        마산회원구: { kanji: '馬山会原区', katakana: 'マサンフェウォング', kanjiKatakana: '馬山会原(マサンフェウォン)区' },
        성산구: { kanji: '城山区', katakana: 'ソンサング', kanjiKatakana: '城山(ソンサン)区' },
        의창구: { kanji: '義昌区', katakana: 'ウィチャング', kanjiKatakana: '義昌(ウィチャン)区' },
        진해구: { kanji: '鎮海区', katakana: 'チンヘグ', kanjiKatakana: '鎮海(チンヘ)区' },
        통영시: { kanji: '統営市', katakana: 'トンヨンシ', kanjiKatakana: '統営(トンヨン)市' },
        하동군: { kanji: '河東郡', katakana: 'ハドングン', kanjiKatakana: '河東(ハドン)郡' },
        함안군: { kanji: '咸安郡', katakana: 'ハムアングン', kanjiKatakana: '咸安(ハムアン)郡' },
        함양군: { kanji: '咸陽郡', katakana: 'ハムヤングン', kanjiKatakana: '咸陽(ハムヤン)郡' },
        합천군: { kanji: '陜川郡', katakana: 'ハブチョングン', kanjiKatakana: '陜川(ハブチョン)郡' },
        제주시: { kanji: '済州市', katakana: 'チェジュシ', kanjiKatakana: 'チェジュ市' },
        서귀포시: { kanji: '西帰浦市', katakana: 'ソギポシ', kanjiKatakana: 'ソギポ市' },
        평양직할시: { kanji: '', katakana: '', kanjiKatakana: '' },
        사리원시: { kanji: '', katakana: '', kanjiKatakana: '' },
        송림시: { kanji: '', katakana: '', kanjiKatakana: '' },
        평산군: { kanji: '', katakana: '', kanjiKatakana: '' },
        길주군: { kanji: '', katakana: '', kanjiKatakana: '' },
        나진시: { kanji: '', katakana: '', kanjiKatakana: '' },
        청진시: { kanji: '', katakana: '', kanjiKatakana: '' },
        함흥시: { kanji: '', katakana: '', kanjiKatakana: '' },
        해주시: { kanji: '', katakana: '', kanjiKatakana: '' },
        안주시: { kanji: '', katakana: '', kanjiKatakana: '' },
        혜산시: { kanji: '', katakana: '', kanjiKatakana: '' },
        강계시: { kanji: '', katakana: '', kanjiKatakana: '' },
        남포: { kanji: '', katakana: '', kanjiKatakana: '' },
        평강군: { kanji: '', katakana: '', kanjiKatakana: '' },
        개성특급시: { kanji: '', katakana: '', kanjiKatakana: '' },
        신의주시: { kanji: '', katakana: '', kanjiKatakana: '' },
        원산시: { kanji: '', katakana: '', kanjiKatakana: '' },
    };
    const keys = Object.keys(data);
    return list.map(v => v.split(' ').map(v => {
        v = v.trim();
        if (keys.includes(v)) {
            if (mode === 0)
                return data[v].kanji;
            else if (mode === 1)
                return data[v].katakana;
            else if (mode === 2)
                return data[v].kanjiKatakana;
            else
                return v;
        }
        else
            return v;
    }).join('　'));
}
exports.japanese = japanese;
